// Set master UI background
Ti.UI.setBackgroundColor('#000');

// Bootstrap core
Ti.include('/core/core.js');

// Initialize App namespace
var App = {
	Device: new Core.Models.Device(),
	MemoryPool: new Core.Models.MemoryPool(),
	Threads: {
		Tasks: new Core.Controllers.Thread('tasks.js')
	},
	Window: Ti.UI.currentWindow
};

// Custom callback on orientation change
Ti.Gesture.addEventListener('orientationchange', function(e){
	var sOrientation = App.Device.orientationToString(e.orientation);
	
	// Only fire event if orientation changes from portrait to landscape (or vice versa)
	if((sOrientation === 'portrait' || sOrientation === 'landscape') && sOrientation !== App.Device.currentOrientation){
		Debug.info('Orientation changed to ' + sOrientation, 1);
		
		var oEvent = {
			currentOrientation: sOrientation
		};
		
		Ti.App.fireEvent('app:orient', oEvent);
	}
});

// Custom callback on network connectivity change
Ti.Network.addEventListener('change', function(e){
	var oEvent = {
		currentNetworkType: App.Device.networkTypeToString(e.networkType),
		isAppOnline: e.online
	}
	
	Ti.App.fireEvent('app:network', oEvent);
});

// Custom callback when we send debugging messages from webviews
Ti.App.addEventListener('app:webDebug', function(e){
	var sText = e.text,
		sLevel = e.level;
		iNewLines = e.newlines ? Math.abs(parseInt(e.newlines)) : 0;
		
	if(typeof Debug[sLevel] != 'function'){
		sLevel = 'info';
	}

	if(isNaN(iNewLines)){
		iNewLines = 0;
	}
	
	Debug[sLevel](sText, iNewLines);
});