/**
 * Supplemental JS contexts (threads)
 * 
 * @author Brad Beebe
 * @since 1.0
 */	
Core.Controllers.Thread = function(sFilename){
	this._pathToFile = Config.PATH_THREAD + sFilename;
	this._thread = {};
	
	if(!Ti.Filesystem.getFile(this._pathToFile).exists()){
		Debug.error('Could not create new JS context: JS file (' + this._pathToFile + ') does not exist');
	}else{
		this._thread = Ti.UI.createWindow({
			url: this._pathToFile,
			width: 1,
			height: 1,
			top: -1,
			left: -1,
			visible: false,
			_isLoaded: true,	// Indicates whether thread window object has been created
			_isActive: false,	// Indicates whether thread window object is active/open
			_isToggling: false	// Indicates whether thread window object is currently opening/closing
		});

		this._thread.addEventListener('open', this.markThreadActive);
		this._thread.addEventListener('close', this.markThreadInActive);

		this._isLoaded = true;
	}
};


/**
 * Callback for thread window open
 * Flags the thread as active
 * 
 * @param object e - Event object
 * @return void
 *
 * @author Brad Beebe
 * @since 1.0
 */
Core.Controllers.Thread.prototype.markThreadActive = function(e){
	e.source._isActive = true;
	e.source._isToggling = false;
};


/**
 * Callback for thread window close
 * Flags the thread as inactive
 * 
 * @param object e - Event object
 * @return void
 *
 * @author Brad Beebe
 * @since 1.0
 */
Core.Controllers.Thread.prototype.markThreadInActive = function(e){
	e.source._isActive = false;
	e.source._isToggling = false;
};


/**
 * Activates/opens the thread window
 * 
 * @return void
 *
 * @author Brad Beebe
 * @since 1.0
 */
Core.Controllers.Thread.prototype.activate = function(){
	if(this._thread._isLoaded === true && this._thread._isActive === false && this._thread._isToggling === false){
		this._thread._isToggling = true;

		this._thread.open();
	}
};


/**
 * De-activates/closes the thread window
 * 
 * @return void
 *
 * @author Brad Beebe
 * @since 1.0
 */
Core.Controllers.Thread.prototype.deactivate = function(){
	if(this._thread._isLoaded === true && this._thread._isActive === true && this._thread._isToggling === false){
		this._thread._isToggling = true;

		this._thread.close();
	}
};