/**
* Text helper methods
* 
* @author Brad Beebe
* @since 1.0
*/
Core.Helpers.Text = {
	/**
	 * Truncate string without breaking word
	 * 
	 * @param string sText
	 * @param integer iLength - Desired maximum length
	 * @param boolean bBreakWork - Break word?
	 * @param boolean bEllipsis - Append ellises?
	 * @return string
	 * 
	 * @author Eric Shelkie
	 * @since 1.0
	 */
	truncate: function(sText, iLength, bBreakWord, bEllipsis){
		// Set default values
		bBreakWord = (typeof bBreakWord !== 'undefined') ? bBreakWord : false;
		bEllipsis = (typeof bEllipsis !== 'undefined') ? bEllipsis : true;

		var lastIndex = iLength;

		if(!bBreakWord){
			sText = sText.substr(0, lastIndex);
			lastIndex = sText.lastIndexOf(' ');
			if(lastIndex < 0) lastIndex = iLength;
		}

		sText = sText.substr(0, lastIndex);
		
		if(bEllipsis){
			sText += '…';
		}

		return sText;
	},


	/**
	 * JS equivalent of str_replace()
	 * 
	 * @link http://phpjs.org/functions/str_replace:527
	 * @return string
	 * 
	 * @author Brad Beebe
	 * @since 1.0
	 */
	replace: function(search, replace, subject, count){
		var i = 0,
		    j = 0,
		    temp = '',
		    repl = '',
		    sl = 0,
		    fl = 0,
		    f = [].concat(search),
		    r = [].concat(replace),
		    s = subject,
		    ra = Object.prototype.toString.call(r) === '[object Array]',
		    sa = Object.prototype.toString.call(s) === '[object Array]';
		s = [].concat(s);
		if (count) {
		    this.window[count] = 0;
		}

		for (i = 0, sl = s.length; i < sl; i++) {
		    if (s[i] === '') {
		        continue;
		    }
		    for (j = 0, fl = f.length; j < fl; j++) {
		        temp = s[i] + '';
		        repl = ra ? (r[j] !== undefined ? r[j] : '') : r[0];
		        s[i] = (temp).split(f[j]).join(repl);
		        if (count && s[i] !== temp) {
		            this.window[count] += (temp.length - s[i].length) / f[j].length;
		        }
		    }
		}
		return sa ? s : s[0];
	}
};


/**
 * Converts a string's slashes to underscores
 * 
 * @author Brad Beebe
 * @since 1.0
 */	
String.prototype.slashToUnderscore = function(){
	return this.replace(/(\/)/g, '_');
};


/**
 * Converts a string's underscores to slashes
 * 
 * @author Brad Beebe
 * @since 1.0
 */	
String.prototype.underscoreToSlash = function(){
	return this.replace(/(_)/g, '/');
};


/**
 * Converts strings from d-s-v to camelCased
 *
 * @author Brad Beebe
 * @since 1.0
 */
String.prototype.dsvToCamelcase = function(){
	var aStr = this.split('-');

	for(var i = 1, ii = aStr.length; i < ii; i++){
		aStr[i] = aStr[i].charAt(0).toUpperCase() + aStr[i].slice(1)
	}

	return aStr.join('');
};


/**
 * Capitalizes first letter of a string
 * 
 * @author Brad Beebe
 * @since 1.0
 */
String.prototype.captialize = function(){
	return this.charAt(0).toUpperCase() + this.slice(1);
};