/**
 * URI helper methods
 * 
 * @author Brad Beebe
 * @since 1.0
 */	
Core.Helpers.Uri = {
	/**
	 * Normalizes URIs to 'path/to/resource' format
	 * 
	 * @param string sUri - A slash-separated URI
	 * @return string
	 * 
	 * @author Brad Beebe
	 * @since 1.0
	 */	
	normalizeUri: function(sUri){
		if(!sUri || typeof sUri != 'string'){
			return sUri;
		}
		
		if(sUri.charAt(0) == '/'){
			sUri = sUri.substr(1, sUri.length);
		}

		if(sUri.charAt(sUri.length - 1) == '/'){
			sUri = sUri.substr(0, sUri.length - 1);
		}
		
		return sUri;
	},


	/**
	 * Build an array composed of the different tiers of a URI
	 * 
	 * @param string sUri - A slash-separated URI
	 * @return array
	 * 
	 * @author Brad Beebe
	 * @since 1.0
	 */		
	buildUriArray: function(sUri){
		sUri = this.normalizeUri(sUri);
		
		return sUri.split('/');
	},
	
	
	/**
	 * Gets the parent URI of a specific URI
	 * 
	 * @param string sUri - A slash-separated URI
	 * @return string
	 * 
	 * @author Brad Beebe
	 * @since 1.0
	 */	
	getParentUri: function(sUri){
		var aUri = this.buildUriArray(sUri)
		
		return aUri.length > 1 ? aUri.slice(0, aUri.length - 1).join('/') : this.normalizeUri(sUri);
	}
};