/**
 * Device settings and methods
 * 
 * @author Brad Beebe
 * @since 1.0
 */	
Core.Models.Device = function(){
	var _this = this;

	this.portraitWidth = 768;
	this.portraitHeight = 1004;

	this.landscapeWidth = 1024;
	this.landscapeHeight = 748;

	this.currentOrientation = this.orientationToString(Ti.UI.orientation);
	
	this.currentNetworkType = this.networkTypeToString(Ti.Network.networkType);
	this.isAppOnline = Ti.Network.online;

	this.platformWidth = this[this.currentOrientation + 'Width'];
	this.platformHeight = this[this.currentOrientation + 'Height'];

	// Adjust orientation properties after our custom callback fires
	Ti.App.addEventListener('app:orient', function(e){
		_this.currentOrientation = e.currentOrientation;

		_this.platformWidth = _this[_this.currentOrientation + 'Width'];
		_this.platformHeight = _this[_this.currentOrientation + 'Height'];
	});

	// Adjust network properties after our custom callback fires
	Ti.App.addEventListener('app:network', function(e){
		_this.currentNetworkType = e.currentNetworkType;
		_this.isAppOnline = e.isAppOnline;
	});
};


/**
 * Determines the orientation of the device based on an orientation constant
 * 
 * @param integer iOrientation - A orientation constant (from Ti.Gesture event listener or Ti.UI.orientation)
 * @return string
 * 
 * @author Brad Beebe
 * @since 1.0
 */
Core.Models.Device.prototype.orientationToString = function(iOrientation){
	switch(iOrientation){
		case Ti.UI.PORTRAIT:
		case Ti.UI.UPSIDE_PORTRAIT:
			return 'portrait';
		break;
		
		case Ti.UI.LANDSCAPE_RIGHT:
		case Ti.UI.LANDSCAPE_LEFT:
			return 'landscape';
		break;
		
		default:
			return 'unknown';
	}
};


/**
 * Determines the current network type of the device based on a network constant
 * 
 * @param integer iNetwork - A network constant (from Ti.Network.change event listener or Ti.networkType)
 * @return string
 * 
 * @author Brad Beebe
 * @since 1.0
 */
Core.Models.Device.prototype.networkTypeToString = function(iNetwork){
	switch(iNetwork){
		case Ti.Network.NETWORK_LAN:
		case Ti.Network.NETWORK_WIFI:
			return 'wifi';
		break;
		
		case Ti.Network.NETWORK_MOBILE:
			return 'mobile';
		break;
		
		default:
			return 'unknown';
	}
};