/**
 * "Memory pool" window to place views marked for garbage collection
 * 
 * @link http://developer.appcelerator.com/question/116867
 * @author Brad Beebe
 * @since 1.0
 */
Core.Models.MemoryPool = function(){
	this.clean();
};


/**
 * Closes any previous memory pool window and starts a new one
 * 
 * @return void
 *
 * @author Brad Beebe
 * @since 1.0
 */
Core.Models.MemoryPool.prototype.clean = function(){
	if(typeof this._winPool === 'object'){
		this._winPool.close();
	}

	this._winPool = Ti.UI.createWindow({
		width: 1,
		height: 1,
		top: -1,
		left: -1,
		visible: false,
		_isActive: false
	});
};


/**
 * Adds views to the memory pool window and then closes it to
 * release it from memory
 * 
 * @param mixed data - Either a single view object or an array of view objects
 * @param boolean bAutoClean - Flag to auto-clean the memory pool
 * @return void
 * 
 * @author Brad Beebe
 * @since 1.0
 */
Core.Models.MemoryPool.prototype.add = function(data, bAutoClean){
	// Do not open the memory pool window until we need it
	if(this._winPool._isActive !== true){
		this._winPool.open();

		this._winPool._isActive = true;
	}

	if(data instanceof Array){
		for(var i = 0, ii = data.length; i < ii; i++){
			this._winPool.add(data[i]);
		}
	}else{
		this._winPool.add(data);
	}

	if(bAutoClean === true){
		this.clean();
	}
};


/**
 * Determines the number of views to be garbage collected once
 * the current memory pool window is closed
 * 
 * @return integer
 *
 * @author Brad Beebe
 * @since 1.0
 */
Core.Models.MemoryPool.prototype.viewCount = function(){
	return !this._winPool.children ? 0 : this._winPool.children.length;
}